# Help / Get Help

## Do you like Django Ninja?

If you like this project, there is a tiny thing you can do to let us know that we're moving in the right direction.

Simply give django-ninja a <a href="https://github.com/vitalik/django-ninja" target="_blank">star on github</a> <a href="https://github.com/vitalik/django-ninja" target="_blank">![github star](img/github-star.png)</a>

or share this URL on social media: 
```
https://django-ninja.dev
```
Follow updates on twitter <a href="https://twitter.com/django_ninja">@django_ninja</a>

## Do you want to help us?

Pull requests are always welcome.

You can inspect our docs for typos and spelling mistakes, and create pull requests or <a href="https://github.com/vitalik/django-ninja/issues" target="_blank">open an issue</a>.

If you have any suggestions to improve **Django Ninja**, please create them as <a href="https://github.com/vitalik/django-ninja/issues" target="_blank">issues</a> on GitHub.


## Do you need help?

Do not hesitate.  Go to <a href="https://github.com/vitalik/django-ninja/issues" target="_blank">GitHub issues</a> and describe your question or problem.  We'll attempt to address them quickly.

Join the chat at our <a href="https://discord.gg/dgE4SNUDTB" target="_blank">Discord</a> server.

[Code-on the webdesign and web development company](https://code-on.be/) gives commercial consulting for Django-Ninja. If you are looking for support please contact Code-on and we will be in touch with you soon.
